"""
    Bloopy

    The Bloopy server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import whsaas.openapi_client
from whsaas.openapi_client.api.destination_api import DestinationApi  # noqa: E501


class TestDestinationApi(unittest.TestCase):
    """DestinationApi unit test stubs"""

    def setUp(self):
        self.api = DestinationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_destination_api_v1_app_app_id_dest_post(self):
        """Test case for create_destination_api_v1_app_app_id_dest_post

        Create Destination  # noqa: E501
        """
        pass

    def test_delete_destination_api_v1_app_app_id_dest_dest_id_delete(self):
        """Test case for delete_destination_api_v1_app_app_id_dest_dest_id_delete

        Delete Destination  # noqa: E501
        """
        pass

    def test_list_destinations_api_v1_app_app_id_dest_get(self):
        """Test case for list_destinations_api_v1_app_app_id_dest_get

        List Destinations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
