"""
    Diahook

    The Diahook server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.8.1
    Generated by: https://openapi-generator.tech
"""


import unittest

import diahook.openapi_client
from diahook.openapi_client.api.authentication_api import AuthenticationApi  # noqa: E501


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self):
        self.api = AuthenticationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_dashboard_access_api_v1_auth_dashboard_access_app_id_post(self):
        """Test case for get_dashboard_access_api_v1_auth_dashboard_access_app_id_post

        Get Dashboard Access  # noqa: E501
        """
        pass

    def test_logout_api_v1_auth_logout_post(self):
        """Test case for logout_api_v1_auth_logout_post

        Logout  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
