"""
    Bloopy

    The Bloopy server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import whsaas.openapi_client
from whsaas.openapi_client.api.application_api import ApplicationApi  # noqa: E501


class TestApplicationApi(unittest.TestCase):
    """ApplicationApi unit test stubs"""

    def setUp(self):
        self.api = ApplicationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_application_api_v1_app_post(self):
        """Test case for create_application_api_v1_app_post

        Create Application  # noqa: E501
        """
        pass

    def test_delete_application_api_v1_app_app_id_delete(self):
        """Test case for delete_application_api_v1_app_app_id_delete

        Delete Application  # noqa: E501
        """
        pass

    def test_list_applications_api_v1_app_get(self):
        """Test case for list_applications_api_v1_app_get

        List Applications  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
