"""
    Diahook

    The Diahook server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.8.1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import diahook.openapi_client
from diahook.openapi_client.model.event_type_in_out import EventTypeInOut


class TestEventTypeInOut(unittest.TestCase):
    """EventTypeInOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEventTypeInOut(self):
        """Test EventTypeInOut"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EventTypeInOut()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
