"""
    Diahook

    The Diahook server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.8.1
    Generated by: https://openapi-generator.tech
"""


import unittest

import diahook.openapi_client
from diahook.openapi_client.api.endpoint_api import EndpointApi  # noqa: E501


class TestEndpointApi(unittest.TestCase):
    """EndpointApi unit test stubs"""

    def setUp(self):
        self.api = EndpointApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_endpoint_api_v1_app_app_id_endpoint_post(self):
        """Test case for create_endpoint_api_v1_app_app_id_endpoint_post

        Create Endpoint  # noqa: E501
        """
        pass

    def test_delete_endpoint_api_v1_app_app_id_endpoint_endpoint_id_delete(self):
        """Test case for delete_endpoint_api_v1_app_app_id_endpoint_endpoint_id_delete

        Delete Endpoint  # noqa: E501
        """
        pass

    def test_get_endpoint_api_v1_app_app_id_endpoint_endpoint_id_get(self):
        """Test case for get_endpoint_api_v1_app_app_id_endpoint_endpoint_id_get

        Get Endpoint  # noqa: E501
        """
        pass

    def test_get_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_get(self):
        """Test case for get_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_get

        Get Endpoint Secret  # noqa: E501
        """
        pass

    def test_list_endpoints_api_v1_app_app_id_endpoint_get(self):
        """Test case for list_endpoints_api_v1_app_app_id_endpoint_get

        List Endpoints  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
