"""
    Bloopy

    The Bloopy server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import whsaas.openapi_client
from whsaas.openapi_client.api.message_api import MessageApi  # noqa: E501


class TestMessageApi(unittest.TestCase):
    """MessageApi unit test stubs"""

    def setUp(self):
        self.api = MessageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_message_api_v1_app_app_id_msg_post(self):
        """Test case for create_message_api_v1_app_app_id_msg_post

        Create Message  # noqa: E501
        """
        pass

    def test_get_message_api_v1_app_app_id_msg_msg_id_get(self):
        """Test case for get_message_api_v1_app_app_id_msg_msg_id_get

        Get Message  # noqa: E501
        """
        pass

    def test_list_messages_api_v1_app_app_id_msg_get(self):
        """Test case for list_messages_api_v1_app_app_id_msg_get

        List Messages  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
