"""
    Bloopy

    The Bloopy server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import whsaas.openapi_client
from whsaas.openapi_client.model.message_in import MessageIn


class TestMessageIn(unittest.TestCase):
    """MessageIn unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMessageIn(self):
        """Test MessageIn"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MessageIn()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
