"""
    Diahook

    The Diahook server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.8.1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import diahook.openapi_client
from diahook.openapi_client.model.message_status import MessageStatus
globals()['MessageStatus'] = MessageStatus
from diahook.openapi_client.model.endpoint_message_out import EndpointMessageOut


class TestEndpointMessageOut(unittest.TestCase):
    """EndpointMessageOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEndpointMessageOut(self):
        """Test EndpointMessageOut"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EndpointMessageOut()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
