"""
    Diahook

    The Diahook server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.8.1
    Generated by: https://openapi-generator.tech
"""


import unittest

import diahook.openapi_client
from diahook.openapi_client.api.event_type_api import EventTypeApi  # noqa: E501


class TestEventTypeApi(unittest.TestCase):
    """EventTypeApi unit test stubs"""

    def setUp(self):
        self.api = EventTypeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_event_type_api_v1_event_type_post(self):
        """Test case for create_event_type_api_v1_event_type_post

        Create Event Type  # noqa: E501
        """
        pass

    def test_delete_event_type_api_v1_event_type_event_type_name_delete(self):
        """Test case for delete_event_type_api_v1_event_type_event_type_name_delete

        Delete Event Type  # noqa: E501
        """
        pass

    def test_list_event_types_api_v1_event_type_get(self):
        """Test case for list_event_types_api_v1_event_type_get

        List Event Types  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
