"""
    Bloopy

    The Bloopy server API documentation  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import whsaas.openapi_client
from whsaas.openapi_client.api.message_attempt_api import MessageAttemptApi  # noqa: E501


class TestMessageAttemptApi(unittest.TestCase):
    """MessageAttemptApi unit test stubs"""

    def setUp(self):
        self.api = MessageAttemptApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_attempt_api_v1_app_app_id_msg_msg_id_dest_dest_id_attempt_attempt_id_get(self):
        """Test case for get_attempt_api_v1_app_app_id_msg_msg_id_dest_dest_id_attempt_attempt_id_get

        Get Attempt  # noqa: E501
        """
        pass

    def test_list_attempted_destinations_api_v1_app_app_id_msg_msg_id_dest_get(self):
        """Test case for list_attempted_destinations_api_v1_app_app_id_msg_msg_id_dest_get

        List Attempted Destinations  # noqa: E501
        """
        pass

    def test_list_attempts_api_v1_app_app_id_msg_msg_id_dest_dest_id_attempt_get(self):
        """Test case for list_attempts_api_v1_app_app_id_msg_msg_id_dest_dest_id_attempt_get

        List Attempts  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
